==> samhain_signed-1.4.2.tar.gz: samhain-1.4.2/profiles/install_post_configopts.sh <==

 

  su _REMOTE_USER_ -c "${RMAKE} deploy >/dev/null"
  su _REMOTE_USER_ -c "${RMAKE} samhain.pk >/dev/null"
 
  cp samhain samhain.deploy
  strip  samhain.deploy >/dev/null 2>&1
  ./sstrip samhain.deploy
  cp sstrip sstrip.deploy
  cp samhain_setpwd samhain_setpwd.deploy
  if test -f exepack; then
    cp exepack exepack.deploy
    cp exepack_fill exepack_fill.deploy
  else
    touch exepack.deploy 
    touch exepack_fill.deploy
  fi

fi

if test "x$1" = "xinstall"; then
  
  if test "x_PREFIX_" = "x/usr"; then
    PIDDIR=/var/run
  elif test "x_PREFIX_" = "x/opt"; then
    PIDDIR=/var/opt/_INSTALL_NAME_
  else
    PIDDIR=_PREFIX_/var/run
  fi

  INSTALLDIR=_PREFIX_/sbin
  if test "x_PREFIX_" = "x/opt"; then
    INSTALLDIR=/opt/_INSTALL_NAME_/bin
  fi

  cp samhain.deploy samhain
  cp samhain_setpwd.deploy samhain_setpwd
  cp sstrip.deploy sstrip
  cp exepack.deploy exepack
  cp exepack_fill.deploy exepack_fill

  ./samhain_setpwd samhain new _PASSWORD_ >/dev/null
  mv samhain.new samhain
  chmod 700 samhain
  ./mkinstalldirs ${PIDDIR}
  ./mkinstalldirs ${INSTALLDIR}
  if test -f samhain; then 
   ./install-sh -m 700 -c samhain ${INSTALLDIR}/_INSTALL_NAME_; 
  else :; 
  fi
  if test -f remote_bootscript; then
    ./remote_bootscript;
  else :; 
  fi

fi

if test "x$1" = "xpack"; then
  
  if test "x_PREFIX_" = "x/usr"; then
    PIDDIR=/var/run
  elif test "x_PREFIX_" = "x/opt"; then
    PIDDIR=/var/opt/_INSTALL_NAME_
  else
    PIDDIR=_PREFIX_/var/run
  fi

  INSTALLDIR=_PREFIX_/sbin
  if test "x_PREFIX_" = "x/opt"; then
    INSTALLDIR=/opt/_INSTALL_NAME_/bin
  fi

  cp samhain.deploy samhain
  cp samhain_setpwd.deploy samhain_setpwd
  cp sstrip.deploy sstrip
  cp exepack.deploy exepack
  cp exepack_fill.deploy exepack_fill

  ./samhain_setpwd samhain new _PASSWORD_ >/dev/null
  mv samhain.new samhain

  test -f exepack.out && rm exepack.out
  ./exepack_fill exepack samhain exepack.out
  mv exepack.out samhain.pk
  chmod 700 samhain.pk

  chmod 700 samhain
  ./mkinstalldirs ${PIDDIR}
  ./mkinstalldirs ${INSTALLDIR}
  if test -f samhain.pk; then 
   ./install-sh -m 700 -c samhain.pk ${INSTALLDIR}/_INSTALL_NAME_; 
  else :; 
  fi
  if test -f remote_bootscript; then
    ./remote_bootscript;
  else :; 
  fi

fi

if test "x$1" = "xmake"; then
  tar -cf sh.ret.tar ./samhain.deploy ./sstrip.deploy \
          ./samhain_setpwd.deploy ./exepack.deploy ./exepack_fill.deploy
else 
  if test "x$1" = "xpack"; then
    if test "x_NOCL_CODE_" = "x"; then
      ./samhain.pk -t init -e none -m none -s none -l none -p err
    else
      echo '-t init -e none -m none -s none -l none -p err' | \
        ./samhain.pk _NOCL_CODE_
    fi
  else
    if test "x_NOCL_CODE_" = "x"; then
      ./samhain -t init -e none -m none -s none -l none -p err
    else
      echo '-t init -e none -m none -s none -l none -p err' | \
        ./samhain _NOCL_CODE_
    fi
  fi
  if test x$? != x0; then 
    echo "samhain -t init: Bad exit status, aborting"
    test -f ./sh_database && rm ./sh_database
    exit 1
  fi
  tar -cf sh.ret.tar ./samhain.deploy ./sstrip.deploy ./samhain_setpwd.deploy \
          ./exepack.deploy ./exepack_fill.deploy ./sh_database
fi

if test x$? != x0; then 
  echo "tar: Bad exit status, aborting"
  test -f ./sh.ret.tar && rm ./sh.ret.tar
  exit 1
fi
 
# this allows to delete the samhain-deploy directory
#
mv ./sh.ret.tar ../sh.ret.tar
exit $?

==> samhain_signed-1.5.3.tar.gz: samhain-1.5.3/profiles/install_post_configopts.sh <==

 

  su _REMOTE_USER_ -c "${RMAKE} deploy >/dev/null"
  cp samhain samhain.deploy
  strip  samhain.deploy >/dev/null 2>&1
  ./sstrip samhain.deploy
  cp sstrip sstrip.deploy

  su _REMOTE_USER_ -c "${RMAKE} samhain.pk >/dev/null"
 
  cp samhain_setpwd samhain_setpwd.deploy
  if test -f exepack; then
    cp exepack exepack.deploy
    cp exepack_fill exepack_fill.deploy
  else
    touch exepack.deploy 
    touch exepack_fill.deploy
  fi

fi

if test "x$1" = "xinstall"; then
  
  if test "x_PREFIX_" = "xUSR"; then
    PIDDIR=/var/run
  elif test "x_PREFIX_" = "xOPT"; then
    PIDDIR=/var/opt/_INSTALL_NAME_
  else
    PIDDIR=_PREFIX_/var/run
  fi

  INSTALLDIR=_PREFIX_/sbin
  if test "x_PREFIX_" = "xOPT"; then
    INSTALLDIR=/opt/_INSTALL_NAME_/bin
  fi

  cp samhain.deploy samhain
  cp samhain_setpwd.deploy samhain_setpwd
  cp sstrip.deploy sstrip
  cp exepack.deploy exepack
  cp exepack_fill.deploy exepack_fill

  ./samhain_setpwd samhain new _PASSWORD_ >/dev/null
  mv samhain.new samhain
  chmod 700 samhain
  ./mkinstalldirs ${PIDDIR}
  ./mkinstalldirs ${INSTALLDIR}
  if test -f samhain; then 
   ./install-sh -m 700 -c samhain ${INSTALLDIR}/_INSTALL_NAME_; 
  else :; 
  fi
  if test -f remote_bootscript; then
    ./remote_bootscript;
  else :; 
  fi

fi

if test "x$1" = "xpack"; then
  
  if test "x_PREFIX_" = "xUSR"; then
    PIDDIR=/var/run
  elif test "x_PREFIX_" = "xOPT"; then
    PIDDIR=/var/opt/_INSTALL_NAME_
  else
    PIDDIR=_PREFIX_/var/run
  fi

  INSTALLDIR=_PREFIX_/sbin
  if test "x_PREFIX_" = "x/opt"; then
    INSTALLDIR=/opt/_INSTALL_NAME_/bin
  fi

  cp samhain.deploy samhain
  cp samhain_setpwd.deploy samhain_setpwd
  cp sstrip.deploy sstrip
  cp exepack.deploy exepack
  cp exepack_fill.deploy exepack_fill

  ./samhain_setpwd samhain new _PASSWORD_ >/dev/null
  mv samhain.new samhain

  test -f exepack.out && rm exepack.out
  ./exepack_fill exepack samhain exepack.out
  mv exepack.out samhain.pk
  chmod 700 samhain.pk

  chmod 700 samhain
  ./mkinstalldirs ${PIDDIR}
  ./mkinstalldirs ${INSTALLDIR}
  if test -f samhain.pk; then 
   ./install-sh -m 700 -c samhain.pk ${INSTALLDIR}/_INSTALL_NAME_; 
  else :; 
  fi
  if test -f remote_bootscript; then
    ./remote_bootscript;
  else :; 
  fi

fi

if test "x$1" = "xmake"; then
  tar -cf sh.ret.tar ./samhain.deploy ./sstrip.deploy \
          ./samhain_setpwd.deploy ./exepack.deploy ./exepack_fill.deploy
else 
  if test "x$1" = "xpack"; then
    if test "x_NOCL_CODE_" = "x"; then
      ./samhain.pk -t init -e none -m none -s none -l none -p err
    else
      echo '-t init -e none -m none -s none -l none -p err' | \
        ./samhain.pk _NOCL_CODE_
    fi
  else
    if test "x_NOCL_CODE_" = "x"; then
      ./samhain -t init -e none -m none -s none -l none -p err
    else
      echo '-t init -e none -m none -s none -l none -p err' | \
        ./samhain _NOCL_CODE_
    fi
  fi
  if test x$? != x0; then 
    echo "samhain -t init: Bad exit status, aborting"
    test -f ./sh_database && rm ./sh_database
    exit 1
  fi
  tar -cf sh.ret.tar ./samhain.deploy ./sstrip.deploy ./samhain_setpwd.deploy \
          ./exepack.deploy ./exepack_fill.deploy ./sh_database
fi

if test x$? != x0; then 
  echo "tar: Bad exit status, aborting"
  test -f ./sh.ret.tar && rm ./sh.ret.tar
  exit 1
fi
 
# this allows to delete the samhain-deploy directory
#
mv ./sh.ret.tar ../sh.ret.tar
exit $?
